@@ -8,11 +8,15 @@ class LandmarkStateVar(StateVar):
   """Variable wrapper of 4x1 numpy array as homogeneous coordinate of a landmark."""
 
   def __init__(self, value: np.ndarray, *, scale: bool = True, **kwargs) -> None:
-    super().__init__(value, 3, **kwargs)
+    super().__init__(3, **kwargs)
     assert value.shape == (4, 1)
+    self._value = value
     self._scale = scale
     self.refresh_homo_scalling()
 
+  def clone(self):
+    raise NotImplementedError
+
   def get_value(self) -> np.ndarray:
     return self._value
 
@@ -24,9 +28,6 @@ class LandmarkStateVar(StateVar):
     self._value += perturbation
     self.refresh_homo_scalling()
 
-  def clone(self):
-    raise NotImplementedError
-
   def refresh_homo_scalling(self) -> None:
     if self._scale:
       # get length of xyz-portion of landmark
