@@ -8,7 +8,11 @@ class TransformStateVar(StateVar):
   """Variable wrapper of lgmath.Transformation."""
 
   def __init__(self, value: Transformation, **kwargs) -> None:
-    super().__init__(value, 6, **kwargs)
+    super().__init__(6, **kwargs)
+    self._value = value
+
+  def clone(self):
+    raise NotImplementedError
 
   def get_value(self) -> Transformation:
     return self._value
@@ -18,6 +22,3 @@ class TransformStateVar(StateVar):
 
   def update(self, perturbation: np.ndarray) -> None:
     self._value.assign(T_ba=se3op.vec2tran(perturbation) @ self._value.matrix())
-
-  def clone(self):
-    raise NotImplementedError
\ No newline at end of file
